NLSL: addprm.f90 File Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

Functions/Subroutines
addprm.f90 File Reference

Go to the source code of this file.

## Functions/Subroutines
subroutine | addprm (ix, ix2, ibd, prmn, prmx, prsc, step, ident)
| Add a parameter to list of parameters being varied for nonlinear least-squares. Also maintain the lists of. More...

## Function/Subroutine Documentation

subroutine addprm | ( | integer | ix,
|  | integer | ix2,
|  | integer | ibd,
|  | double precision | prmn,
|  | double precision | prmx,
|  | double precision | prsc,
|  | double precision | step,
|  | character*9 | ident
| ) |  |

Add a parameter to list of parameters being varied for nonlinear least-squares. Also maintain the lists of.

1. ixst : secondary parameter index (for multiple sites/spectra)
2. ibnd : boundary flag for variable parameter
3. prmin : minimum for variable parameter
4. prmax : maximum for variable parameter
5. prscl : desired accuracy for given parameter
6. xfdstp : Size of forward-differences step
7. tag : Name of the parameter (character*9)
8. ixx : index of each element in the fparm array into the x vector

The values of these parameters for the given variable parameter are passed to ADDPRM:

subroutine parameter | kept in list
--- | ---
ix2 | ixst
ibd | ibnd
prmn | prmin
prmx | prmax
prsc | prscl
step | xfdstp
ident | tag

Notes:

- Each addition to the list is included in sort order with respect to the index ix. This is an artifact of the original implementation of the program, and no longer required.
- If ix2 = -1, the parameter specified by ix is to be varied individually for EACH existing site/spectrum If ix2 = 0, the parameter is to be varied for ALL sites/spectra at once

Definition at line 54 of file addprm.f90.

Here is the caller graph for this function: